var CALENDAR_NAMES = {
    month: {
        en: [ "January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December" ],
        pl: [ "Styczeń", "Luty", "Marzec", "Kwiecień", "Maj", "Czerwiec", "Lipiec", "Sierpień", "Wrzesień", "Październik", "Listopad", "Grudzień" ]
    },
    dayname: {
        en: [ "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday", "Sunday" ],
        pl: [ "Poniedziałek", "Wtorek", "Środa", "Czwartek", "Piątek", "Sobota", "Niedziela" ]
    },
    shortDayname: {
        en: [ "Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun" ],
        pl: [ "Pn", "Wt", "Śr", "Cz", "Pt", "So", "Nd" ],
    }
};

// ==========================================
//              Date / Calendar
// ==========================================

function launchDate() {
    var $date_section = $("form article section.date").first();
    var article_tag = $date_section.closest("article").attr("class");
    if($date_section.length && $date_section.find("input.type").val() == "date") {
        // ====== Date in multipost (sortable) ======
        if($date_section.closest("article").attr("class").indexOf("multi_") == 0 && $("#site_sort_by_date").val() == "true") {
            setTimeout(function() {
                $("article section .date_box").closest("article").each(function() {
                    $(this).find(".buttons").children(".up, .down, .jump").hide();
                });
                $("article section .date_box").closest(".article_group").addClass("disable-sortable");
                if(sortByInput(article_tag, "date") == true) {
                    //showPopup(LOCALIZE["post-sorted-by-date"]);
                    showPopup("fi-calendar", LOCALIZE["post-sorted-by-date"], LOCALIZE["ok-label"]);
                    $("#popup_box .confirm").click(function() { hidePopup(); });
                }
            }, ANIMATION_TIME * 2)
        }
        initializeDateInput();
    }
};

function dateToFormat(date, format) {
// -------------------------------------------
// date = <string> eg. "1977-07-29"
// format = <string> eg. "dd-mm-yyyy"
// -------------------------------------------
// RETURN: <string> Date converted from Xable standard yyyy-mm-dd to user format
// -------------------------------------------
    if(date && date.length >= 8 && date.length == format.length) {
        date = date.split("-") // 0=year, 1=month, 2=day
        if(date.length == 3) {
            return format.replace("yyyy", date[0]).replace("mm", date[1]).replace("dd", date[2]);
        }
        else {
            return false;
        }
    }
    else {
        return false;
    };
};

function formatToDate(date, format) {
// -------------------------------------------
// date = <string> eg. "29-07-1977"
// format = <string> eg. "dd-mm-yyyy"
// -------------------------------------------
// RETURN: <string> Date converted from user format to Xable standard yyyy-mm-dd
// -------------------------------------------
    if(date.length >= 8 && date.length == format.length) {
        date = [
                    date.substr(format.indexOf("yyyy"), 4),
                    date.substr(format.indexOf("mm"), 2),
                    date.substr(format.indexOf("dd"), 2)
        ];
        if(date && !isNaN(date[0]) && !isNaN(date[1]) && !isNaN(date[2])) {
            return date.join("-");
        }
        else {
            return false;
        }
    }
    else {
        return false;
    }
};

function saveDate($section) {
// -------------------------------------------
// $section = <object> Section containing date input field
// -------------------------------------------
// Validate date format & put it to input.date in format yyyy-mm-dd
// -------------------------------------------
    $input = $section.find(".date_box input").first();
    var options = $section.find("input.options").first().val().split(";");
    var date = $input.val();
    var format = $("#site_date_format").val();
    if(date == "") {
        if(options.indexOf("required") < 0) {
            $section.find("input.date").val(""); // Allow empty input
        }
        else {
            showPopup("fi-alert", LOCALIZE["required-date-alert"], "OK");
            $("#popup_box .confirm").click(function() { hidePopup(); loadData($section); $input.focus(); });
        }
    }
    else if(date = formatToDate(date, format)) {
        $section.find("input.date").val(date);
        $input.val(dateToFormat(date, format)); // Fix spacer characters
        $input.blur();
    }
    else {
        showPopup("fi-alert", LOCALIZE["invalid-date-format"] + ":<br>" + format, "OK");
        $("#popup_box .confirm").click(function() { hidePopup(); loadData($section); $input.focus(); });
    }
};

function loadData($section) {
// -------------------------------------------
// $section = <object> Section containing date input field
// -------------------------------------------
// Get data from input.date and show it in user format in input with calendar
// -------------------------------------------
    var options = $section.find("input.options").first().val().split(";");
    var date = $section.find("input.date").val();
    var format = $("#site_date_format").val();
    if(date.length >= 8 && format.length >= 8) {
        date = date.split("-") // 0=year, 1=month, 2=day
        format = format.replace("yyyy", date[0]).replace("mm", date[1]).replace("dd", date[2]);
        $section.find(".date_box input").first().val(format);
    }
};

function initializeCalendar($date) {
// -------------------------------------------
// $date = <object> date input
// -------------------------------------------
// (re)INITIALIZE: calendar buttons actions
// -------------------------------------------
    $calendar = showCalendarPopup();
    updateWeekdays($calendar);

    date_string = $date.val();
    if(date_string == "") { date_string = currentTime("yyyy-mm-dd"); };
    date = new Date(date_string);

    updateMonth($calendar, date);
    updateDays($calendar, date);
    updateSelectedDate($calendar, $date);
    initializeSetDate($calendar, $date);

    // ====== Month Change ======
    $calendar.find(".nav button").unbind("click").click(function() {
        $(this).blur();

        $tables = $calendar.find(".tables");
        if($(this).attr("class") == "prev_month") {
            date = new Date($calendar.find("table.days .in_month").first().attr("data-date"));
            date.setDate(date.getDate() - 1);
            $tables.animate({ "left": "100%" }, ANIMATION_TIME, function() { $(this).css({ "left": "-100%" })});
        }
        else { // next_month
            date = new Date($calendar.find("table.days .in_month").last().attr("data-date"));
            date.setDate(date.getDate() + 1);
            $tables.animate({ "left": "-100%" }, ANIMATION_TIME, function() { $(this).css({ "left": "100%" })});
        };

        updateDays($calendar, date); // To match box height
        setTimeout(function () { // wait for slide animation
            $tables.animate({ "left": "0" }, ANIMATION_TIME / 2);
            updateMonth($calendar, date);
            updateSelectedDate($calendar, $date);
            initializeSetDate($calendar, $date);
        }, ANIMATION_TIME);
    });

    // ====== Close Button ======
    $calendar.find("button.close").click(function() { $(this).blur(); hideCalendarPopup(); });
    $(document).keyup(function(e) { if (e.keyCode === 27) { hideCalendarPopup(); }; });  
};

function showCalendarPopup() {
// -------------------------------------------
// $date = <object> date input
// -------------------------------------------
// Show: Calendar popup
// Returns: <object> Calendar DOM object
// -------------------------------------------
    html = "";
    // ====== Month HEADER ======
    html = html +
        "<div class='header'>" +
            "<p class='title'><span class='fi-calendar'></span></p>" +
            "<button class='close'><span class='icon fi-x'></span></button>" +
        "</div>";
    // ====== Month HEADER ======
    html = html +
        "<div class='nav'>" +
            "<p class='month'>-</p>" +
            "<button class='prev_month'><span class='icon fi-arrow-left'></span></button>" +
            //"<button class='prev_month'><span class='icon'>&lt;</span></button>" +
            "<button class='next_month'><span class='icon fi-arrow-right'></span></button>" +
            //"<button class='next_month'><span class='icon'>&gt;</span></button>" +
        "</div>";
    // ====== Daynames & days Tables ======
    html = html +
        "<div class='tables'>" +
            "<table class='daynames'></table>" +
            "<table class='days'></table>" +
        "</div>";
    // ====== Show POPUP ======
    $("body").find(".calendar_box").remove();
    $("body").append("<div id='page_fader'></div>" + "<div id='calendar_box'>" + html + "</div>");
    $("#page_fader, #calendar_box").fadeIn(ANIMATION_TIME);

    return $("#calendar_box");

};

function hideCalendarPopup() {
// -------------------------------------------
// Hide & remove calendar popup
// -------------------------------------------
    $("#page_fader, #calendar_box").fadeOut(ANIMATION_TIME / 2, function() { $(this).remove(); });
    $(document).unbind("keyup");
};

function updateWeekdays($calendar) {
// -------------------------------------------
// $calendar = <object> div.calendar DOM object
// -------------------------------------------
// UPDATES: Displayed weekday names list
// -------------------------------------------
    html = "";
    daynames = CALENDAR_NAMES["shortDayname"][ADMIN_LANG];
    for(i in daynames) {
        i = parseInt(i);
        html = html + "<td class='weekday_" + (i + 1) + "'><span>" + daynames[i] + "</span></td>"
    }
    $table = $calendar.find("table.daynames");
    $table.find("tr").remove();
    $table.append("<tr>" + html + "</tr>");
};

function updateMonth($calendar, date) {
// -------------------------------------------
// $calendar = <object> div.calendar DOM object
// date = <object> Date
// -------------------------------------------
// UPDATES: Displayed Month & year in calendar
// -------------------------------------------
    html = CALENDAR_NAMES["month"][ADMIN_LANG][date.getMonth()] +
        " <span class='year'>" + date.getFullYear() + "</span>";
    $month = $calendar.find(".month");
    $month.html(html);
};

function updateDays($calendar, date) {
// -------------------------------------------
// $calendar = <object> div.calendar DOM object
// date = <object> Date
// -------------------------------------------
// UPDATES: Days in calendar
// -------------------------------------------
    var monthDays = getMonthDays(date, "week");
    var month = dateToString("mm", date);
    var today = new Date();
    var rows = [];
    var html = "";

    for(i in monthDays) {
        day = monthDays[i];

        //alert(dateToString("mm-dd / W", day));
        weekday = parseInt(dateToString("W", day));
        dayString = dateToString("yyyy-mm-dd", day);
        attr = [];
        attr[attr.length] =  "weekday_" + weekday;
        attr[attr.length] =  "date_" + dayString;

        if(dateToString("mm", day) == month) {
            attr[attr.length] = "in_month";
            if(day.toDateString() == today.toDateString()) { attr[attr.length] = "current_day"; }; // not mark on outside month view
        }
        else {
            attr[attr.length] = "outside_month";
        };

        html = html + "<td class='" + attr.join(" ") + "' data-date='" + dayString + "'><span>" + dateToString("D", day) + "</span></td>\n";
        if(weekday == 7 && html != "") {
            rows[rows.length] = "<tr>" + html + "</tr>";
            html = "";
        };
    }

    $table = $calendar.find("table.days");
    $table.find("tr").remove();
    $table.append(rows.join("\n"));
};

function initializeSetDate($calendar, $date) {
// -------------------------------------------
// $calendar = <object> div.calendar DOM object
// $date = <object> date input
// -------------------------------------------
// Initialize: Set date by clicking a day & close popup
// -------------------------------------------
    $calendar.find("table.days td.in_month").click(function() {
        $calendar.find("table.days td.in_month").unbind("click");

        date = $(this).attr("class").split("date_").pop().split(" ").shift();
        $date.val(date);
        loadData( $date.closest("section") );

        updateSelectedDate($calendar, $date);
        setTimeout(function() {
            hideCalendarPopup();
            scrollToSorted($date.closest("section"));
        }, ANIMATION_TIME);
    })
};

function updateSelectedDate($calendar, $date) {
// -------------------------------------------
// $calendar = <object> div.calendar DOM object
// $date = <object> date input
// -------------------------------------------
// UPDATES: Selected cell highliht update
// -------------------------------------------
    selected_date = $date.val();
    $calendar.find("td i.marker").remove();
    $calendar.find(".days .selected").removeClass("selected");
    $selected = $calendar.find(".date_" + selected_date);
    if($selected.length && $selected.attr("class").indexOf("in_month") > -1) {
        $selected.addClass("selected");
        $selected.append("<i class='marker'></i>");
    }
};

function initializeDateInput() {
    // Load date(s) from php
    $("form section .date_box").each(function() {
        $section = $(this).closest("section");
        var date = $section.find("input.date").val();
        var options = $section.find("input.options").val().split(";");
        var format = $("#site_date_format").val();

        // Options
        if(options.indexOf("required") > -1) {
            if(date.length < format.length) {
                date = currentTime("yyyy-mm-dd");
                $section.find("input.date").val(date);
            };
        };

        // Show date in user format
        if(date = dateToFormat(date, format)) {
            $section.find(".date_box input").first().val(date);
        }
    });

    // Calendar button
    $("form section .date_box button").unbind("click").click(function() {
        $section = $(this).closest("section");
        if($section.find(".date_box input").prop("disabled") != true) {
            initializeCalendar( $section.find("input.date") );
        };
        $(this).blur();
        return false;
    });
};

// ==========================================
//              Sort Articles
// ==========================================

function sortByInput(article_tag, sort_tag) {
    $articles = $("form article." + article_tag);
    if($articles.length > 1) {
        var posts = {};
        var n = 0;
        $articles.each(function() {
            date = $(this).find("section." + sort_tag + " input.date").first().val();
            if(date != "") {
                id = date + "_[" + ($articles.length - n) + "]";
                posts[id] = $(this);
                n++;
            }
        });
        //$articles.remove();
        $articles_group = $articles.parent(".article_group");
        sorted_keys = Object.keys(posts).sort().reverse();
        
        if(Object.keys(posts).join(";") != sorted_keys.join(";")) {
            $articles_group.slideUp(ANIMATION_TIME, function() {
                for(i in sorted_keys) {
                    id = sorted_keys[i];
                    $article = posts[id];
                    $articles_group.append( $article.clone() );
                    $article.remove();
                }
                $articles_group.slideDown(ANIMATION_TIME);
                reinitializePostActiveElements();
            });
            return true;
        }
        else {
            reinitializePostActiveElements();
            return false;
        }
    }
};

function scrollToSorted($section) {
    if($("#site_sort_by_date").val() == "true") {
        var section_tag = $section.attr("class");
        var article_tag = $section.closest("article").attr("class");
        $section.attr("data-sort", "updated");

        if(sortByInput(article_tag, section_tag) == true) {
            setTimeout(function() {
                var $moved = false;
                $("form article section." + section_tag).each(function() {
                    if($(this).attr("data-sort") == "updated") {
                        scrollTo($(this).closest("article"));
                        $(this).removeAttr("data-sort");
                    }
                });
            }, ANIMATION_TIME * 3)
        }
    }
};

// ==========================================
//            Order Sort Options
// ==========================================

function launchOrderTagMap() {
    if(typeof(TAG_MAP) == "object") {
        // Items list
        var items = {};
        $("article._order").each(function() {
            items[ $(this).find("h3").attr("path") ] = $(this);
        });
        for(tag in TAG_MAP) {
            for(path in TAG_MAP[tag]) {
                if(Object.keys(items).indexOf(path) > -1) {
                    var html = "<input type='hidden' class='" + tag + "' value='" + TAG_MAP[tag][path] + "'>";
                    items[path].append(html);
                }
            }
        }
    }
};

function sortByTag(tag, dir) {
// ----------------------------------------------
// tag = <string> order data element TAG
// dir = <number> order DIRection: 1 or -1
// ----------------------------------------------
// Sort articles by specified data
// ----------------------------------------------
    $(".ui-drop-box").remove();

    if(dir != -1) { dir = 1; }; // order direction
    time = 100;
    delay = 50;
    transition = 200;
    error = 0;
    articles = {};
    $articles = $("#cms.order article._order");
    $articles.slideUp(transition);
    setTimeout(function() {
        var num = 0;
        error_text = LOCALIZE["tag-not-found"];
        pre_length = $("#cms.order article._order").length;
        $("#cms.order article._order").each(function() {
            
            if($(this).data("ui-draggable")) { $(this).draggable("destroy"); };
            
            $tag = $(this).find(tag);
            if($tag.length) {

                if($tag.prop("tagName") == "INPUT") { key = $tag.val(); }
                else { key = $tag.text().makeId(); };

                if(typeof(key) == "string" && key != "") {
                    articles[key + "_" + num++] = $(this);
                }
                else {
                    error = error_text.replace("@tag", tag).replace("@path", $(this).find("h3").attr("path"));
                    showPopup("fi-prohibited", error, "OK", false);
                    $("#popup_box .confirm").click(function() { hidePopup(); });
                    error++;
                }
            }
            else {
                error = error_text.replace("@tag", tag).replace("@path", $(this).find("h3").attr("path"));
                showPopup("fi-prohibited", error, "OK", false);
                $("#popup_box .confirm").click(function() { hidePopup(); });
                error++;
            };
        });
        if(error == 0) {
            sorted_keys = Object.keys(articles).sort();
            if(dir == -1) { sorted_keys.reverse(); };
            for(i in sorted_keys) {
                $article = articles[ sorted_keys[i] ];
                $("main").append($article.clone());
                time = time + delay;
                $("#cms.order article._order").last().delay(time).slideDown(transition / 2);
            };
            $articles.remove();
            setTimeout(function() {
                reinitializePostActiveElements();
            }, transition * 2);
            
            //setTimeout(function() {
            //    alert(pre_length + " / " + $("#cms.order article._order").length);
            //}, 2000);
        }
        else {
            $articles.show();
        }
    }, transition + time)
};

function getOrderOptions() {
// ----------------------------------------------
// RETURN: <array>
// Get all order options from HTML
// ----------------------------------------------
    var order_options = [];
    $("#cms.order ._order-options li").each(function() {
        $button = $(this).find("button");
        $input = $(this).find("input");
        if($input.length) {
            typ = $input.attr("type");
            key = $input.attr("class").split(" ").shift();
            if(typ == "checkbox") { val = $input.prop("checked"); }
            else { val = $input.val(); }
        }
        else if($button.length) {
            key = $button.attr("class").split(" ").shift();
            val = true;
        }
        else {
            val = false;
        };
        if(val == true || val == "true") { order_options[order_options.length] = key; };
    });
    return order_options;
};

function initializeOrderOptions() {
    if(getOrderOptions().indexOf("auto") > -1) { $("#cms.order article._order .buttons").hide(); };

    $("#cms.order ._order-options li input.auto").change(function() {
        auto = $(this).prop("checked");
        if(auto) {
            sortByTag("h3 span." + ADMIN_LANG, 1);
            $("#cms.order article._order .buttons").fadeOut(200);
        }
        else {
            $("#cms.order article._order .buttons").fadeIn(200);
        };
    });

    $("#cms.order ._order-options button.date").click(function() {
        $(this).blur();
        sortByTag(".header-date", -1);
        return false;
    });
};