// ==========================================
//           Float HEADER Buttons
// ==========================================

function showButtons($buttons) {
    if(parseInt($buttons.css("margin-top")) < 50) {
        $buttons.addClass("float_buttons").stop().animate({ "margin-top": "-15px" }, ANIMATION_TIME);
    };
};

function hideButtons($buttons) {
    $buttons.stop().animate({ "margin-top": "-100px", "opacity": 0 }, ANIMATION_TIME / 2, function() {
        $buttons.attr("style", "");
    });
};

function floatButtons() {
    if($("header .buttons button").length) {
        $buttons = $("header .float_buttons");
        scroll = $(window).scrollTop();
        if(scroll < SCROLL_MEMO && scroll < ($(window).height() * 1.1)) {
            hideButtons($buttons);
        }
        else if(scroll > SCROLL_MEMO && scroll > ($(window).height() * 0.5)) {
            showButtons($buttons);
        };
        SCROLL_MEMO = scroll;
    }
};

function launchFloatHeader() {
    // Add float buttons copy
    $("header .buttons").after($("header .buttons")[0].outerHTML);
    $("header .buttons").last().addClass("float_buttons");
    $(window).scroll(function() { floatButtons(); });
    setTimeout(function() { SCROLL_MEMO = 0; floatButtons(); }, 500);
}

// ==========================================
//              Header Buttons
// ==========================================

function deleteEmptyUploads() {
// ----------------------------
// Remove unused upload inputs due to max 24 input limits may be used simultaneously
// ----------------------------
// RETURNS: <true> if done / <false> if too many uploads detected & show Upload popup
// ----------------------------
    var $empty_fields = $();
    var $upload_fields = $();
    $("input.upload_file").each(function() {
        if($(this).val()) {
            $upload_fields = $upload_fields.add($(this));
        }
        else {
            $empty_fields = $empty_fields.add($(this));
        }
    });
    //alert("upload: "+ $upload_fields.length + "\nempty: " + $empty_fields.length);
    if($upload_fields.length <= 24) {
        $empty_fields.remove();
        if($upload_fields.length) { $("#upload_info").fadeIn(500); }
        $upload_fields.prop('disabled', false); // Unblock blocked by UploadCancelFix()
        return true;
    }
    else {
        alert(LOCALIZE["upload-inputs-limit-html"])
        return false;
    };
};

function requireTitle(tags) {
// ----------------------------
// tags = <array> or <string> section(s) reuired title tag in Header
// ----------------------------
// CHECK: if title was filled by user and disable publish/save if wasn't
// ----------------------------
    var $title = $();
    titles = [ "title", "name" ];
    if(typeof tags == "string") { titles = titles.concat(tags.split(",")); }
    else if(typeof tags == "object") { titles = titles.concat(tags); };
    // Find title
    for(i in titles) {
        tag = titles[i];
        $section = $("main article.header section." + tag);
        if(!$title.length && $section.length) {
            $title = $section.find("input." + LANG);
        }
    };
    // Check title content
    if($title.length) {
        title = $title.val();
        if(typeof title != "string" || title.trim() == "") {
            infoPopup(LOCALIZE['title-required']);
            $title.focus();
            return false;
        }
        else {
            return true;
        }
    }
    // No title found
    else {
        return true;
    }
};

function hideButtonsOnTemplate() {
    if(EDIT_PATH.path("extension") == "template") {
        var to_hide = [ "discard", "unpublish", "revert" ];
        $("header .buttons button").each(function() {
            var action = $(this).attr("class");
            if(typeof(action) == "string" && to_hide.indexOf(action.split(" ").shift()) >= 0) {
                $(this).hide();
            }
        })
    }
};

function launchHeaderButtons() {
    
    // Hide useless buttons on template (create new page)
    hideButtonsOnTemplate();
    
    // Rename publish to save on template edit
    if(SAVE_PATH.path("extension") == "template") {
        $("header .buttons button.save").text(LOCALIZE["save-label"]);
    };

    // Cancel / reset changes
    $("header button.cancel").click(function() {
        $(this).blur();
        if(detectChanges()) {
            url = window.location.href.split("?");
            if(url.length > 1) {
                get = url.pop().split("&");
                for(i in get) {
                    if(get[i].substr(0, 5) == "lang=") { get[i] = "lang=" + LANG; };
                }
                get = get.join("&");
            }
            else {
                get = "path=" + CURRENT_PATH + "&lang=" + LANG;
            };
            $("#confirm_popup button").unbind();
            showPopup("fi-refresh", LOCALIZE["cancel-changes-alert"], LOCALIZE["yes-no-buttons"]);
            $("#popup_box .confirm").click(function() {
                $(this).blur();
                if(EDIT_PATH.path("extension") == "template") {
                    $("#loader").fadeIn(500);
                    location.href = "index.php";
                }
                else {
                    $("#loader").fadeIn(500);
                    location.href = "index.php?" + get;
                };
            });        
            $("#popup_box .cancel").click(function() {
                $(this).blur();
                hidePopup();
                $(this).unbind();
            });
            $(this).blur();
            return false;
        }
        else {
            infoPopup(LOCALIZE['no-changes-done']);
            $(this).blur();
            return false;
        };
    });

    $("header button.publish").click(function () {
        $(this).blur();
        if(!requireTitle()) {
            return false;
        }
        else if(detectChanges() || EDIT_PATH.path("extension") == "draft") {
            updateOutput();
            deleteEmptyUploads();
            return true;
        }
        else {
            infoPopup(LOCALIZE['nothing-to-publish']);
            return false;
        };
    });

    $("header button.save").click(function () {
        $(this).blur();
        if(SAVE_PATH.indexOf("/_templates/") < 0 && !requireTitle()) {
            return false;
        }
        else if(detectChanges()) {
            updateOutput();
            deleteEmptyUploads();
            return true;
        }
        else {
            infoPopup(LOCALIZE['no-changes-done']);
            return false;
        };
    });

    $("header button.discard").click(function () {
        $(this).blur();
        if($("input#published_version").val() != "true") {
            infoPopup(LOCALIZE["draft-only-info"]);
            return false;
        }
        else if(EDIT_PATH.path("extension") != "draft") {
            infoPopup(LOCALIZE["nothing-to-discard"]);
            return false;
        }
        else {
            $form = $(this).closest("form");
            updateOutput();
            showPopup("fi-trash", LOCALIZE["discard-changes-confirm"], LOCALIZE["yes-no-buttons"]);
            $("#popup_box .confirm").click(function() {
                $(this).blur();
                name = $button.attr("name");
                val = $button.val();
                $form.prepend("<input name='" + name + "' value='" + val + "'>").submit();
                // Please wait info
                $("#upload_info p").text(LOCALIZE["please-wait"]);
                $("#upload_info").fadeIn(500);
            });        
            $("#popup_box .cancel").click(function() {
                $(this).blur();
                hidePopup();
                $(this).unbind();
            });
            return false;
        };
    });

    $("header button.unpublish").click(function () {
        $(this).blur();
        file_path = SAVE_PATH.substr(SITE_ROOT.length + 1);
        if(file_path.path("dirname") == "") {
            infoPopup("Ten dokument musi posiadać wersję publiczną");
            return false;
        }
        else if($("input#published_version").val() == "true") {
            $form = $(this).closest("form");
            updateOutput();
            showPopup("fi-prohibited", LOCALIZE["unpublish-changes-confirm"], LOCALIZE["yes-no-buttons"]);
            $("#popup_box .confirm").click(function() {
                name = $button.attr("name");
                val = $button.val();
                $form.prepend("<input name='" + name + "' value='" + val + "'>").submit();
                // Please wait info
                $("#upload_info p").text(LOCALIZE["please-wait"]);
                $("#upload_info").fadeIn(500);
            });        
            $("#popup_box .cancel").click(function() {
                hidePopup();
                $(this).unbind();
            });
            return false;
        }
        else {
            infoPopup(LOCALIZE["nothing-to-unpublish"]);
            return false;
        };
    });

    $("header button.revert").click(function () {
        $(this).blur();
        if($("input#previous_version").val() == "true") {
            $form = $(this).closest("form");
            updateOutput();
            showPopup("fi-rewind", LOCALIZE["revert-to-previous-confirm"], LOCALIZE["yes-no-buttons"]);
            $("#popup_box .confirm").click(function() {
                name = $button.attr("name");
                val = $button.val();
                $form.prepend("<input name='" + name + "' value='" + val + "'>").submit();
                // Please wait info
                $("#upload_info p").text(LOCALIZE["please-wait"]);
                $("#upload_info").fadeIn(500);
            });
            $("#popup_box .cancel").click(function() {
                hidePopup();
                $(this).unbind();
            });
        }
        else {
            infoPopup(LOCALIZE["nothing-to-revert"]);
            $(this).blur().css("outline", "none");
        }
        return false;
    });
};

// ==========================================
//            User & Notifications
// ==========================================

function launchHeaderPulldowns() {
    $(".pull_down").mouseenter(function() { $(this).find("li").stop().show(200); });
    $(".pull_down").mouseleave(function() { $(this).find("li").stop().hide(200); });

    $("#menu_user .user_logout").click(function() { hrefAction("_logout.php?info=" + encodeURI(LOCALIZE["logout-info"])); });
    $("#menu_user .user_password").click(function() { hrefAction("password.php?page=" + SAVE_PATH); });
    $("#menu_notifications .old_backup").click(function() { hrefAction("backup.php?page=" + SAVE_PATH); });
    $("#menu_notifications .new_edit").click(function() { hrefAction("index.php?path=" + $(this).attr("path")); });

    $("#menu_notifications .show_log").click(function() {
        href = "show-log.php?back_url=" + SAVE_PATH;
        if(detectChanges()) {
            showPopup("fi-alert", LOCALIZE["unsaved-changes-alert"], LOCALIZE["yes-no-buttons"]);
            $("#popup_box .confirm").click(function() { location.href = href; });
            $("#popup_box .cancel").click(function() { hidePopup(); return false; });
            $(this).blur();
            return false;
        }
        else {
            $("#loader").fadeIn(500);
            location.href = href;
            $(this).blur();
            return true;
        }
    });
};

function hrefAction(href) {
    if(detectChanges()) {
        showPopup("fi-alert", LOCALIZE["unsaved-changes-alert"], LOCALIZE["yes-no-buttons"]);
        $("#popup_box .confirm").click(function() { location.href = href; });
        $("#popup_box .cancel").click(function() { hidePopup(); return false; });
        $(this).blur();
        return false;
    }
    else {
        $("#loader").fadeIn(500);
        location.href = href;
        $(this).blur();
        return true;
    };
};

// ==========================================
//          Unpublished changes list
// ==========================================

var UNPUBLISHED_HTML = [];

function launchUnpublishedList() {
    $("dd > .nav_item").each(function() {
        var find = [ "draft", "unpublished" ];
        var $item = $(this).find(".item_label");
        var $item_flag = $item.find(".active_mode");
        if($item_flag.length && typeof($item_flag.attr("class")) == "string") {
            var status = $item_flag.attr("class").split("color_").pop().split(" ").shift();
            var href = $item.attr("href");
            if(find.indexOf(status) > -1 && typeof(href) == "string" && href != "") {
                if($item.find("span." + ADMIN_LANG)) {
                    var title = $item.find("span." + ADMIN_LANG).text();
                }
                else {
                    var title = $item.find("p").text();
                };
                if(typeof(title) != "string" || title == "") {
                    title = href.path("filename");
                };
                
                var html = "<li>" +
                    "<figure class='icon_box'><span class='fi-flag color_" + status + "'></span></figure>" +
                    "<a href='index.php?path=" + decodeURI(href) + "' class='text_box'><span class='title'>" + title + "</span><br><span class='light_info'>" + href + "</span></a>" +
                    "</li>";
                UNPUBLISHED_HTML[UNPUBLISHED_HTML.length] = html;
            }
        }
    })
    
    var $notification = $("header li.unpublished_list");
    var num = Object.keys(UNPUBLISHED_HTML).length;
    if($notification.length && num > 0) {
        
        // Update unpublished number
        html = $notification.html().replace("@num", num);
        $notification.html(html);
        
        // Show popup
        $notification.click(function() {
            $(this).blur();
            var html = "<h3>" + LOCALIZE["unpublished-list"] + "</h3><ul>\n" + UNPUBLISHED_HTML.join("\n") + "\n</ul>"  + "<div id='close_popup'><button class='cancel'><i class='fi-x'></i></button></div>";
            $("body").append("<div id='info_box' class='unpublished_list'><p>-</p></div>");
            $("#info_box").html(html).fadeIn(500);
            
            $("body").css("overflow-y", "hidden");
            
            $("#info_box button.cancel").click(function() {
                $("#info_box").fadeOut(250, function() {
                    $(this).remove();
                })
                $("body").css("overflow-y", "scroll");
            })
        })
        
    }
    else {
        // Hide unbublished info
        $notification.remove();
    }
};
